@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (null, "JS.ScriptMathProcessor", ["java.lang.Float", "java.util.Hashtable", "JU.A4", "$.AU", "$.BS", "$.CU", "$.DF", "$.Lst", "$.M3", "$.M4", "$.P3", "$.P4", "$.PT", "$.Quat", "$.V3", "JM.BondSet", "JS.SV", "$.T", "JU.BSUtil", "$.Escape", "$.Logger"], function () {
+Clazz.load (null, "JS.ScriptMathProcessor", ["java.util.Hashtable", "JU.A4", "$.AU", "$.BS", "$.CU", "$.DF", "$.Lst", "$.M3", "$.M4", "$.P3", "$.P4", "$.PT", "$.Quat", "$.V3", "JM.BondSet", "JS.SV", "$.T", "JU.BSUtil", "$.Escape", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.wasX = false;
 this.asBitSet = false;
@@ -178,7 +178,6 @@ return this.wasX = true;
 }, "JU.M4");
 Clazz.defineMethod (c$, "addXFloat", 
 function (x) {
-if (Float.isNaN (x)) return this.addXStr ("NaN");
 this.putX (JS.SV.newF (x));
 return this.wasX = true;
 }, "~N");
@@ -786,9 +785,9 @@ case 268435538:
 if (x1.tok != 10 || x2.tok != 10) return false;
 return this.addXBs (JU.BSUtil.toggleInPlace (JU.BSUtil.copy (x1.value), x2.value));
 case 268435858:
-return this.addXBool (x1.tok == 2 && x2.tok == 2 ? x1.intValue <= x2.intValue : x1.asFloat () <= x2.asFloat ());
+return this.addXBool (x1.tok == 2 && x2.tok == 2 ? x1.intValue <= x2.intValue : x1.isNaN () && x2.isNaN () || x1.asFloat () <= x2.asFloat ());
 case 268435857:
-return this.addXBool (x1.tok == 2 && x2.tok == 2 ? x1.intValue >= x2.intValue : x1.asFloat () >= x2.asFloat ());
+return this.addXBool (x1.tok == 2 && x2.tok == 2 ? x1.intValue >= x2.intValue : x1.isNaN () && x2.isNaN () || x1.asFloat () >= x2.asFloat ());
 case 268435856:
 return this.addXBool (x1.tok == 2 && x2.tok == 2 ? x1.intValue > x2.intValue : x1.asFloat () > x2.asFloat ());
 case 268435859:
@@ -980,11 +979,11 @@ var lnew =  new JU.Lst ();
 for (var i = l.size (); --i >= 0; ) {
 var pt1 = JU.P3.newP (JS.SV.ptValue (l.get (i)));
 m4.rotTrans (pt1);
-lnew.add (pt1);
+lnew.addLast (pt1);
 }
 return this.addXList (lnew);
 }
-return this.addXStr ("NaN");
+return this.addXFloat (NaN);
 case 8:
 pt = JU.P3.newP (x1.value);
 switch (x2.tok) {
