@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JU");
-Clazz.load (["javajs.api.GenericZipTools"], "JU.ZipTools", ["java.io.BufferedInputStream", "$.IOException", "java.lang.Boolean", "java.util.zip.CRC32", "$.GZIPInputStream", "$.ZipEntry", "$.ZipInputStream", "javajs.api.GenericZipInputStream", "$.Interface", "JU.BArray", "$.Lst", "$.Rdr", "$.SB"], function () {
+Clazz.load (["javajs.api.GenericZipTools"], "JU.ZipTools", ["java.io.BufferedInputStream", "$.IOException", "java.lang.Boolean", "java.util.zip.CRC32", "$.GZIPInputStream", "$.ZipEntry", "$.ZipInputStream", "javajs.api.GenericZipInputStream", "$.Interface", "$.ZInputStream", "JU.BArray", "$.Lst", "$.Rdr", "$.SB"], function () {
 c$ = Clazz.declareType (JU, "ZipTools", null, javajs.api.GenericZipTools);
 Clazz.makeConstructor (c$, 
 function () {
@@ -388,6 +388,10 @@ c$.deActivatePngZipB = Clazz.defineMethod (c$, "deActivatePngZipB",
 if (JU.Rdr.isPngZipB (bytes)) bytes[51] = 32;
 return bytes;
 }, "~A");
+Clazz.overrideMethod (c$, "isZipStream", 
+function (br) {
+return Clazz.instanceOf (br, javajs.api.ZInputStream);
+}, "~O");
 Clazz.defineStatics (c$,
 "b512", null);
 });
